(function (window, $, document, undefined)
{
    /**
     * Class that manages the front page carousel.
     * @constructor
     */
    Carousel = function ()
    {
        this._registerListeners();
        this._currentItem = 1;
        this._interval = null;
    };

    Carousel.prototype.play = function ()
    {
        var instance = this;
        this._interval = setInterval(function() {
            // increment current item
            instance._currentItem = (instance._currentItem % 3) + 1;

            // click
            var selector = ".carousel-container .tab .overlay[data-item='" + instance._currentItem + "']";
            $(selector).click();

        }, 5000);// 5 second delay

        var $btn = $(".carousel-button");
        $btn.removeClass("play");
        $btn.addClass("pause");
    };

    Carousel.prototype.pause = function ()
    {
        clearInterval(this._interval);
        var $btn = $(".carousel-button");
        $btn.removeClass("pause");
        $btn.addClass("play");
    };

    Carousel.prototype._registerListeners = function ()
    {
        var instance = this;

        // Add listeners to the carousel tabs
        $(".carousel-container .tab .overlay").on("click", function (e)
        {
            var item = $(this).data("item");
            instance._currentItem = item;

            // Activate the selected image and hide the others
            $(".carousel-container .tab-image img").each(function ()
            {
                var $image = $(this);
                if (item === $image.data("item")) {
                    $image.addClass("enabled");
                } else {
                    $image.removeClass("enabled");
                }
            });

            // Activate the selected tab and hide the others
            $(".carousel-container .tab").each(function ()
            {
                var $tab = $(this);
                if (item === $tab.data("item")) {
                    $tab.addClass("enabled");
                } else {
                    $tab.removeClass("enabled");
                }
            });

            //start interval timer over on click
            clearInterval(instance._interval);
            instance.play();

        });

        // Show pause/play button when hovering over image
        $(".carousel-container .tab-image img").hover(
            function (e) {
                e.stopPropagation();
                $(".carousel-button").stop(true, true).fadeIn();
            },
            function (e) {
                // only stop showing the button if you aren't hovering over the button itself
                if( !$(e.relatedTarget).hasClass("carousel-button") ) {
                    $(".carousel-button").stop(true, true).fadeOut();
                }
            }
        );

        // Handle pause/play button click
        $(".carousel-button").on("click", function() {
            var $button = $(this);
            if( $button.hasClass('pause') ) {
                instance.pause();
            } else {
                instance.play();
            }

        });
    };

    $(document).ready(function ()
    {
        new Carousel().play();
    });

})(window, jQuery, document);